# SoundBridge
Spotify LedFx Sonos Proxy

## About

This project tries to make an Spotify LedFX Sonos proxy, meaning it will show up as an spotify connect device allowing you to stream music to this device.
Then the "proxy" part will kick in and will get the incoming spotify audio to both ledfx and a sonos device of your chosing, allowing you to headless hear and see your music.

Currently WIP